#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: celestia
# PROJECT HOMEPAGE 	: http://www.shatters.net/celestia/
# SOURCE           	: http://prdownloads.sourceforge.net/celestia/
#
# AUTHOR         	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION   : 2009-06-13 
#
# BUILD-ONLY DEPS	: -
# NOTES				: compiled with lua, which is not needed for running the program (it seems)

### Setting main variables
NAME="celestia"
VERSION="svn.09.06.13"
ARCH="i686"
CPU="i686"
BUILD=62.1
EXT="txz"

VERZ="svn"
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION

HOMEPAGE="http://www.shatters.net/celestia/"
DESCRIPTION="3D space simulation"
SRCLNK=$URL/$NAME-$VERSION.tar.gz

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NAME-$VERZ
ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
DOCS="ABOUT-NLS AUTHORS *.txt ChangeLog COPYING INSTALL NEWS README TRANSLATORS"

#~ PATCH=celestia-1.4.1-gcc-4.1.patch
#~ PATCHLNK=$URL/$NAME/$PATCH
#~ MAN=CelestiaUsersGuide1-4-1.pdf
#~ MANLNK=$URL/$NAME/$MAN

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Checking if patch is present. If it's not, download it
#~ if [ -f $PATCH ]; then
	#~ echo "Patch is already present, no need to download it";
#~ else
 	#~ echo "Downloading patch..."
	#~ wget -c -nv $PATCHLNK
#~ fi

#~ ### Checking if guide is present. If it's not, download it
#~ if [ -f $MAN ]; then
	#~ echo "Manual is already present, no need to download it";
#~ else
 	#~ echo "Downloading manual..."
	#~ wget -c -nv $MANLNK
#~ fi

### Extracting source
tar xfv $SRCPKG

### Patch
cd $SRCDIR
#~ patch -p0 < $CWD/celestia-1.4.1-gcc-4.1.patch || exit 1

### Configure, make, install
cd $SRCDIR
autoreconf -iv
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man --with-gtk --disable-static --disable-debug || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
#~ find $PKGDIR/usr/man -type f -exec gzip -9 {} \;
#~ cp -a $CWD/$MAN $PKGDIR/usr/doc/$NAME-$VERSION

### Adding build-file, patch, guide to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
#~ cp -a $CWD/$PATCH $PKGDIR/usr/src/$NAME-$VERSION

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME: 
$NAME: Celestia is a free space simulation that lets you explore our 
$NAME: universe in three dimensions. Unlike most planetarium software, 
$NAME: Celestia doesn't confine you to the surface of the Earth. You can 
$NAME: travel throughout the solar system, to any of over 100,000 stars, 
$NAME: or even beyond the galaxy.
$NAME: Check also http://www.celestiamotherlode.net for lots of celestia 
$NAME: add-ons.
$NAME: 
$NAME: $HOMEPAGE
EOF

### Desktop entry
sed -i "s@Astronomy;Science;Application;@Astronomy;Science;Education;Application@" $PKGDIR/usr/share/applications/$NAME.desktop 

### Icon
cp -a $PKGDIR/usr/share/pixmaps/$NAME.png $ICONDIR || exit 1

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Removing pixmaps 
rm -fr $PKGDIR/usr/share/pixmaps

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT

### md5
cd $CWD
md5sum $PKG.$EXT > $PKG.md5

### dep
depfinder $PKG.$EXT > $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK #$PATCHLNK $MANLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
